@@ -1,4 +1,4 @@
-/* $Id: sycls.c,v 1.62 2004/06/20 21:48:05 gerhard Exp $ */
+/* $Id: sycls.c,v 1.63 2004/09/18 12:12:27 gerhard Exp $ */
 /* Copyright Gerhard Rieger 2001-2004 */
 /* Published under the GNU General Public License V.2, see file COPYING */
 
@@ -721,10 +721,10 @@ pid_t Fork(void) {
 pid_t Waitpid(pid_t pid, int *status, int options) {
    int _errno;
    pid_t retval;
-   Debug3("waitpid(%d, %p, %d)", pid, status, options);
+   Debug3("waitpid("F_pid", %p, %d)", pid, status, options);
    retval = waitpid(pid, status, options);
    _errno = errno;
-   Debug2("waitpid(, {%d}, ) -> %d", *status, retval);
+   Debug2("waitpid(, {%d}, ) -> "F_pid, *status, retval);
    errno = _errno;
    return retval;
 }
@@ -751,6 +751,14 @@ int Sigaction(int signum, const struct sigaction *act,
 }
 #endif /* HAVE_SIGACTION */
 
+unsigned int Alarm(unsigned int seconds) {
+   unsigned int retval;
+   Debug1("alarm(%u)", seconds);
+   retval = alarm(seconds);
+   Debug1("alarm() -> %u", retval);
+   return retval;
+}
+
 int Kill(pid_t pid, int sig) {
    int retval, _errno;
    Debug2("kill("F_pid", %d)", pid, sig);
