@@ -1,5 +1,5 @@
-/* $Id: sycls.h,v 1.38 2003/10/23 05:42:57 gerhard Exp $ */
-/* Copyright Gerhard Rieger 2001-2003 */
+/* $Id: sycls.h,v 1.40 2004/09/21 19:11:24 gerhard Exp $ */
+/* Copyright Gerhard Rieger 2001-2004 */
 /* Published under the GNU General Public License V.2, see file COPYING */
 
 #ifndef __sycls_h_included
@@ -80,6 +80,7 @@ typedef RETSIGTYPE (*sighandler_t)(int);
 sighandler_t Signal(int signum, sighandler_t handler);
 int Sigaction(int signum, const struct sigaction *act,
 	      struct sigaction *oldact);
+unsigned int Alarm(unsigned int seconds);
 int Kill(pid_t pid, int sig);
 int Execvp(const char *file, char *const argv[]);
 int System(const char *string);
@@ -197,6 +198,7 @@ void Add_history(const char *string);
 #define Waitpid(p,s,o) waitpid(p,s,o)
 #define Signal(s,h) signal(s,h)
 #define Sigaction(s,a,o) sigaction(s,a,o)
+#define Alarm(s) alarm(s)
 #define Kill(p,s) kill(p,s)
 #define Execvp(f,a) execvp(f,a)
 #define System(s) system(s)
