@@ -1,4 +1,4 @@
-/* $Id: xio-progcall.c,v 1.42 2004/06/20 21:32:14 gerhard Exp $ */
+/* $Id: xio-progcall.c,v 1.43 2004/08/22 06:24:47 gerhard Exp $ */
 /* Copyright Gerhard Rieger 2001-2004 */
 /* Published under the GNU General Public License V.2, see file COPYING */
 
@@ -487,7 +487,11 @@ int _xioopen_foxec(char *comma,
 	       applyopts(fdi, *copts, PH_LATE2);
 	    }
       } /* withfork */
- 
+      else {
+	 applyopts(-1, *copts, PH_LATE);
+	 applyopts(-1, *copts, PH_LATE2);
+      }
+
       /* what to do with stderr? */
       if (withstderr) {
 	 /* handle it just like ordinary process output, i.e. copy output fd */
