@@ -1,4 +1,4 @@
-/* $Id: xio-socks.c,v 1.20 2004/06/20 21:30:02 gerhard Exp $ */
+/* $Id: xio-socks.c,v 1.22 2004/08/25 15:54:36 gerhard Exp $ */
 /* Copyright Gerhard Rieger 2001-2004 */
 /* Published under the GNU General Public License V.2, see file COPYING */
 
@@ -21,6 +21,7 @@ enum {
 } ;
 
 #define SOCKSPORT "1080"
+#define BUFF_LEN (SIZEOF_STRUCT_SOCKS4+512)
 
 static int xioopen_socks4_connect(char *a1, int rw, xiofile_t *fd,
 				  unsigned groups, int dummy1, int dummy2,
@@ -48,11 +49,10 @@ static int xioopen_socks4_connect(char *a1, int rw, xiofile_t *xxfd,
    struct sockaddr_in themsa, *them = &themsa;
    bool needbind = false;
    bool lowport = false;
-   unsigned char buff[8+256];
+   unsigned char buff[BUFF_LEN];
    struct socks4 *sockhead = (struct socks4 *)buff;
    size_t buflen = sizeof(buff);
    int socktype = SOCK_STREAM;
-   /*0 unsigned char infobuff[256];*/
    int level;
    int result;
 
@@ -269,10 +269,17 @@ int
    }
 #endif /* WITH_SOCKS4A */
 #if WITH_SOCKS4A
-   /* this has not really been tested */
    if (host == NULL) {
-      strncpy((char *)&sockhead->dest+3, hostname, 256+8-*headlen);
+      /* SOCKS4A requires us to append the host name to resolve
+         after the user name's trailing 0 byte.  */
+      char* insert_position = (char*) sockhead + *headlen;
+
+      strncpy(insert_position, hostname, BUFF_LEN-*headlen);
+      ((char *)sockhead)[BUFF_LEN-1] = 0;
       *headlen += strlen(hostname) + 1;
+      if (*headlen > BUFF_LEN) {
+	 *headlen = BUFF_LEN;
+      }
    }
 #endif /* WITH_SOCKS4A */
    return STAT_OK;
